
# 变量文件

变量文件属于Robotframework的高级用法，详情请看[Robotframework-变量文件](https://robotframework-userguide-cn.readthedocs.io/zh_CN/latest/CreatingTestData/ResourceAndVariableFiles.html#variable-files)

一般来讲我们测试的过程中并不需要用到变量文件，但是如果想要做一些更加骚的操作可以去研究一下用法。

举个例子：

比如如果我们想要直接能够用${道具名}的方式在测试脚本里引用这个道具id，那么robot脚本的做法是你得在“Variables”里自己定义这个变量。

```robot

*** Variables ***
${金币}     1001
${改名卡}   12000

*** Test Cases ***

测试改名
    ...

    发送GM命令    addItem   ${改名卡}   1

```

道具表那么多道具，一个个加很麻烦，有没有办法可以遍历配置表直接把所有道具变量都生成呢？
那就要用到变量文件。

写一个python脚本，实现get_variables方法
```python
# items.py
def get_variables():
    items = {}

    # 这是伪代码，怎么读取配置表需要自己实现
    # 读取道具配置表
    data_cfg = load("道具.xlsx")
    for data in data_cfg:
        # 把道具名作为变量名，id作为值
        item[data['name']] = data['id']
    
    # 返回这个变量表
    return items

```

```robot
*** Settings ***

Variable    Variables/items.py  # 引入这个变量文件

*** Test Cases ***
测试改名
    ...

    发送GM命令    addItem   ${改名卡}   1       # 现在你可以通过变量名访问道具id了
```

能利用这个机制做什么还是结合实际情况来看，平时应该用不上。
